﻿using System;
using System.Linq;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using Syncfusion.UI.Xaml.Charts;

namespace WPF
{
    public class XAxisTypeToPrimaryAxisConverter : IMultiValueConverter
    {
        public Visibility Visibility { get; set; }

        public object Convert(object[] values, Type targetType, object parameter, System.Globalization.CultureInfo culture)
        {

            if (values == null) throw new ArgumentNullException("values");
            if (values.Count() != 2) throw new ArgumentException();

            var isNumerical = (bool)values[0];
            var xLabel = (string)values[1];
            ChartAxis axis;

            if (isNumerical)
                axis = new NumericalAxis();
            else
                axis = new CategoryAxis();

            axis.Header = xLabel;
            axis.Visibility = Visibility;

            SetStyle(axis);
            
            return axis;
        }

        private static void SetStyle(ChartAxis axis)
        {
            var dataTemplate = new DataTemplate();
            var txtBlock = new FrameworkElementFactory(typeof(TextBlock));

            txtBlock.SetBinding(TextBlock.TextProperty, new Binding("LabelContent"));
            txtBlock.SetValue(TextBlock.FontSizeProperty, 10d);

            dataTemplate.VisualTree = txtBlock;
            
            axis.LabelsIntersectAction = AxisLabelsIntersectAction.None;
            axis.EdgeLabelsDrawingMode = EdgeLabelsDrawingMode.Shift; // edgelabeldrawing mod
          //  axis.PlotOffset = 40; // also we can set plotoffset to avoid overflow
            axis.LabelRotationAngle = -25;
            axis.LabelTemplate = dataTemplate;
        }

        public object[] ConvertBack(object value, Type[] targetTypes, object parameter, System.Globalization.CultureInfo culture)
        {
            throw new NotImplementedException();
        }
    }
}